You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@uima.apache.org by sc...@apache.org on 2016/05/06 18:27:21 UTC

svn commit: r1742581 - /uima/uimaj/branches/experiment-v3-jcas/uimaj-core/src/main/java/org/apache/uima/cas/CASRuntimeException.java

Author: schor
Date: Fri May  6 18:27:21 2016
New Revision: 1742581

URL: http://svn.apache.org/viewvc?rev=1742581&view=rev
Log:
[UIMA-4670] add a messasge

Modified:
    uima/uimaj/branches/experiment-v3-jcas/uimaj-core/src/main/java/org/apache/uima/cas/CASRuntimeException.java

Modified: uima/uimaj/branches/experiment-v3-jcas/uimaj-core/src/main/java/org/apache/uima/cas/CASRuntimeException.java
URL: http://svn.apache.org/viewvc/uima/uimaj/branches/experiment-v3-jcas/uimaj-core/src/main/java/org/apache/uima/cas/CASRuntimeException.java?rev=1742581&r1=1742580&r2=1742581&view=diff
==============================================================================
--- uima/uimaj/branches/experiment-v3-jcas/uimaj-core/src/main/java/org/apache/uima/cas/CASRuntimeException.java (original)
+++ uima/uimaj/branches/experiment-v3-jcas/uimaj-core/src/main/java/org/apache/uima/cas/CASRuntimeException.java Fri May  6 18:27:21 2016
@@ -60,8 +60,11 @@ public class CASRuntimeException extends
 
 	/** Error accessing type system: the type system has not been committed. */
 	public static final String TYPESYSTEM_NOT_LOCKED = "TYPESYSTEM_NOT_LOCKED";
-
-	/** Can't create FS of type "{0}" until the type system has been committed. */
+	
+	/** Can''t add an array type "{0}" to the type system after the type system has been committed. */
+  public static final String ADD_ARRAY_TYPE_AFTER_TS_COMMITTED = "ADD_ARRAY_TYPE_AFTER_TS_COMMITTED";
+  
+	/** Can''t create FS of type "{0}" until the type system has been committed. */
 	public static final String CREATE_FS_BEFORE_TS_COMMITTED = "CREATE_FS_BEFORE_TS_COMMITTED";
 	
   /** Cannot request the Java Class for a UIMA type before type system commit **/